master/fsm_master.c
changeset 1029 61ffe5f22306
parent 1028 afdd4bdbb7ec
child 1031 000593b576dd
--- a/master/fsm_master.c	Wed Jun 18 12:49:11 2008 +0000
+++ b/master/fsm_master.c	Wed Jun 18 13:33:50 2008 +0000
@@ -260,9 +260,9 @@
                 slave = master->slaves + i;
                 ec_slave_init(slave, master, i, i + 1);
 
                 // do not force reconfiguration in operation mode to avoid
                 // unnecesssary process data interruptions
-                if (master->mode != EC_MASTER_MODE_OPERATION)
+                if (master->phase != EC_OPERATION)
                     slave->force_config = 1;
             }
@@ -260,9 +260,9 @@
                 ec_slave_init(slave, master, i, i + 1);
 
-                // do not force reconfiguration in operation mode to avoid
+                // do not force reconfiguration in operation phase to avoid
                 // unnecesssary process data interruptions